@@ -1,5 +1,5 @@
 /*
- * Copyright © 2007-2009 Gerd Kohlberger <lowfi@chello.at>
+ * Copyright © 2007-2010 Gerd Kohlberger <gerdko gmail com>
  *
  * This file is part of Mousetweaks.
  *
@@ -20,7 +20,6 @@
 #ifndef __MT_MAIN_H__
 #define __MT_MAIN_H__
 
-#include <gdk/gdkx.h>
 #include <gconf/gconf-client.h>
 
 #include "mt-timer.h"
@@ -34,10 +33,9 @@ struct _MtData {
     GConfClient *client;
     GtkBuilder  *ui;
     MtService   *service;
-    MtTimer     *delay_timer;
+    MtTimer     *ssc_timer;
     MtTimer     *dwell_timer;
     MtCursor    *cursor;
-    Display     *xtst_display;
     gint         n_screens;
     gint         direction;
     gint         pointer_x;
@@ -50,16 +48,17 @@ struct _MtData {
     gint         style;
     gint         dwell_mode;
     gint         dwell_dirs[4];
-    guint        delay_enabled  : 1;
+    guint        ssc_enabled    : 1;
     guint        dwell_enabled  : 1;
     guint        dwell_show_ctw : 1;
     guint        animate_cursor : 1;
 
     /* state flags */
+    guint        left_handed           : 1;
     guint        dwell_drag_started    : 1;
     guint        dwell_gesture_started : 1;
     guint        override_cursor       : 1;
-    guint        move_release          : 1;
+    guint        ssc_finished          : 1;
 };
 
 G_END_DECLS
